/*
 * Generic serial functions  (compatible with PalmOS 2.0)
 *
 *  $Id: serial.c,v 1.19 2001/10/02 15:05:43 ldrolez Exp $ 
 *
 *  Copyright (C) 2000 Ludovic Drolez
 *
 *   This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
 *
 */

#include <PalmOS.h>
#include <Core/System/SerialMgrOld.h>

#include "palmwac.h"
#include "main_rsrc.h"

static UInt16  gSerialRefNum;

/*
 * Initialise the serial port (v2 api)
 */
Err     SerialOpen (UInt32 baud)
{
   Err     err;
   //SerSettingsPtr set;

   err = SysLibFind ("Serial Library", &gSerialRefNum);
   ErrNonFatalDisplayIf (err != 0, "Can't find serial library");

   err = SerOpen (gSerialRefNum, 0, baud);
   if (err != 0) {
      if (err == serErrAlreadyOpen) {
	 FrmAlert(SerialInUseAlert);
	 SerClose (gSerialRefNum);
      }
      else
	 FrmAlert(CantopenserialAlert);
	 return true;
   }
   //set->flags = serSettingsFlagStopBits1 | serSettingsFlagBitsPerChar8;
   //SerSetSettings(gSerialRefNum, set); 
   //SerGetSettings(gSerialRefNum, set);
   //set->flags |= serSettingsFlagCTSAutoM;    
   //SerSetSettings(gSerialRefNum, set);

   // do we really need that ?
   // err = SerSetReceiveBuffer (gSerialRefNum, gSerialBuffer,
   //			      sizeof (gSerialBuffer));
   return err;
}

void    SerialClose (void)
{
   // restore the default buffer before closing the serial port
   //SerSetReceiveBuffer (gSerialRefNum, gSerialBuffer, 0);
   SerClose (gSerialRefNum);
}

Err     SerialTx (void *buf, UInt32 count, UInt32 *nbytes)
{
   Err err;
   *nbytes = SerSend (gSerialRefNum, buf, count, &err);
   return err;
}

Err     SerialRx (void *buf, UInt32 count, UInt32 timeout, UInt32 *nbytes)
{
   Err err;
   *nbytes = SerReceive (gSerialRefNum, buf, count, timeout, &err);
   return err;
}

Err     SerialRxCheck (UInt32 *nbytes)
{
   Err err;
   err = SerReceiveCheck (gSerialRefNum, nbytes);
   if (err == serErrLineErr) {
      SerReceiveFlush (gSerialRefNum, 0);
      Debug ("serial error");
   }
   return err;
}

Err     SerialTxString(Char *s)
{
   UInt32 nbytes;
   return SerialTx(s, StrLen (s), &nbytes);
}
